<?php

namespace Litecms\MatrixSetting\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\MatrixSetting\Models\MatrixSetting;

class MatrixSettingPolicy
{

    /**
     * Determine if the given user can view the matrix_setting.
     *
     * @param UserPolicy $user
     * @param MatrixSetting $matrix_setting
     *
     * @return bool
     */
    public function view(UserPolicy $user, MatrixSetting $matrix_setting)
    {
        if ($user->canDo('matrix_setting.matrix_setting.view') && $user->isAdmin()) {
            return true;
        }

        return $matrix_setting->user_id == user_id() && $matrix_setting->user_type == user_type();
    }

    /**
     * Determine if the given user can create a matrix_setting.
     *
     * @param UserPolicy $user
     * @param MatrixSetting $matrix_setting
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('matrix_setting.matrix_setting.create');
    }

    /**
     * Determine if the given user can update the given matrix_setting.
     *
     * @param UserPolicy $user
     * @param MatrixSetting $matrix_setting
     *
     * @return bool
     */
    public function update(UserPolicy $user, MatrixSetting $matrix_setting)
    {
        if ($user->canDo('matrix_setting.matrix_setting.edit') && $user->isAdmin()) {
            return true;
        }

        return $matrix_setting->user_id == user_id() && $matrix_setting->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given matrix_setting.
     *
     * @param UserPolicy $user
     * @param MatrixSetting $matrix_setting
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, MatrixSetting $matrix_setting)
    {
        return $matrix_setting->user_id == user_id() && $matrix_setting->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given matrix_setting.
     *
     * @param UserPolicy $user
     * @param MatrixSetting $matrix_setting
     *
     * @return bool
     */
    public function verify(UserPolicy $user, MatrixSetting $matrix_setting)
    {
        if ($user->canDo('matrix_setting.matrix_setting.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given matrix_setting.
     *
     * @param UserPolicy $user
     * @param MatrixSetting $matrix_setting
     *
     * @return bool
     */
    public function approve(UserPolicy $user, MatrixSetting $matrix_setting)
    {
        if ($user->canDo('matrix_setting.matrix_setting.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
