<?php

namespace Litecms\MatrixSetting\Providers;

use Illuminate\Support\ServiceProvider;

class MatrixSettingServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'matrix_setting');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'matrix_setting');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('litecms.matrix_setting', function ($app) {
            return $this->app->make('Litecms\MatrixSetting\MatrixSetting');
        });

                // Bind MatrixSetting to repository
        $this->app->bind(
            'Litecms\MatrixSetting\Interfaces\MatrixSettingRepositoryInterface',
            \Litecms\MatrixSetting\Repositories\Eloquent\MatrixSettingRepository::class
        );

        $this->app->register(\Litecms\MatrixSetting\Providers\AuthServiceProvider::class);
                $this->app->register(\Litecms\MatrixSetting\Providers\EventServiceProvider::class);
        
        $this->app->register(\Litecms\MatrixSetting\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.matrix_setting'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litecms/matrix_setting.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/matrix_setting')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/matrix_setting')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
